@@ -24,7 +24,9 @@ API_PATH = "https://{}/v1/webapi".format("10.81.41.1:3080") \
 
 CODEPRODUIT = {
     "i-Parapheur": "IP",
-    "Pastell": "PA"
+    "Pastell": "PA",
+    "web-delib": "WD",
+    "web-DPO": "DP",
 }
 
 
